import { nanoid } from 'nanoid';
import { agent } from './agent.ts';
import { ai } from './ai.ts';
/**
 * 清除文本中的@信息
 * @param text
 */
const clearAtInfo = (text: string = '') => {
  const newText = text.replace(/@[\u4e00-\u9fa5\w]+/g, '').replace(/#.*?#/g, '');
  return newText.trim();
};

const cmdList: {
  cmd: string;
  description?: string;
  callPath?: {
    path?: string;
    key?: string;
  };
}[] = [
  {
    cmd: '指令夸人',
    description: `进行夸奖`,
    callPath: {
      path: 'tools',
      key: 'good-job',
    },
  },
];
const getTextCmd = (text: string, cmdList = []) => {
  const text20 = text.length > 20 ? text.slice(0, 20) : text;
  const cmd = cmdList.find((item) => text20.includes(item.cmd));
  if (cmd) {
    return cmd;
  }
  return {
    cmd: undefined,
  };
};
agent
  .route({
    path: 'xhs',
  })
  .define(async (ctx) => {
    const { text = '' } = ctx.query || {};
    const id = nanoid();
    const no_at_text = clearAtInfo(text);
    const cmd = getTextCmd(no_at_text, cmdList);
    if (cmd.cmd) {
      const newText = no_at_text.replace(cmd.cmd, '').trim();
      if (cmd.callPath) {
        const res = await agent.call({
          path: cmd.callPath.path,
          key: cmd.callPath.key,
          payload: {
            text: newText,
          },
        });
        ctx.body = res.body || '';
      }
      return;
    }
    const resFix = await agent.call({
      path: 'fix',
      key: 'xhs',
      payload: {
        text: no_at_text,
      },
    });
    if (resFix.code !== 200) {
      ctx.throw(500, 'AI 小红书prompt优化错误: ' + resFix.message);
      return;
    } else {
      console.log('小红书优化的文本', resFix.body);
    }
    const prompt_text = resFix.body || '';
    const res = await ai
      .chat(
        [
          {
            role: 'user',
            content: prompt_text,
          },
        ],
        {
          // @ts-ignore
          enable_thinking: false,
        },
      )
      .catch((error) => {
        ctx.throw(500, 'AI 服务错误: ' + error.status);
        return error;
      });
    ctx.body = res.choices?.[0]?.message?.content || '';
  })
  .addTo(agent);
